Learn R Programming

eufmdis.adapt (version 0.1.0)

cleanup_names: Clean up a vector of column names

Description

The function takes a vector of column names as an argument and returns a cleaned up version of it.

Usage

cleanup_names(x)

Value

A character vector

Arguments

x

A character vector

Author

Ian Kopacka

Details

The following changes are made: - names are converted to lower case - dots are replaced by underscores - underscores in the beginning and end of a string are removed - multiple underscores are replaced by a single one